/****************************************************************************
 *
 * Activity.hh
 *
 * This file is part of bpel2qnbound
 *
 * Copyright (C) 2007, 2018 Moreno Marzolla
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 ****************************************************************************/

#ifndef BPEL_ACTIVITY_HH
#define BPEL_ACTIVITY_HH

#include <libxml/tree.h>
#include <string>
#include "Visitable.hh"

/**
 * This class represents an abstract BPEL activity. All concrete
 * implementations of BPEL activities inherit from this class.
 */
class Activity : public Visitable {
protected:
    static int s_id; ///< Unique ID count

    int m_id; ///< Unique ID of this activity
    const std::string m_name;

    /**
     * Builds an activity corresponding to an XML BPEL node fragment
     *
     * @param name the name of the activity, as results from the
     * "name" attribute
     */
    Activity( const std::string& name ) : Visitable( ), m_id( s_id++ ), m_name( name ) { };

public:
    virtual ~Activity( ) { };

    /**
     * Returns the unique ID of this activity.
     *
     * @return the unique ID of this activity
     */
    int get_id( void ) const { return m_id; }

    /**
     * Returns the name of this activity
     *
     * #return the name of this activity
     */
    std::string get_name( void ) const { return m_name; };

    /**
     * Describes the current activity; this method outputs a textual
     * description of this activity.
     */
    virtual void describe( void ) const = 0;

};

#endif
