/****************************************************************************
 *
 * BPELModel.cc
 *
 * This file is part of bpel2qnbound
 *
 * Copyright (C) 2007, 2018 Moreno Marzolla
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 ****************************************************************************/
#include "BPELModel.hh"
#include "WSDLOperation.hh"
#include "ActivityVisitor.hh"

#include <iostream>
#include <cstdlib>

using namespace std;

BPELModel::BPELModel( const string& name ) :
    m_name( name ),
    m_root_activity( 0 ),
    m_type( closed_workload ),
    m_population( 0 ),
    m_think_time( 0.0 ),
    m_arrival_rate( 0.0 )
{

}

BPELModel::~BPELModel( )
{

}

void BPELModel::add_operation( WSDLOperation* op )
{
    if ( m_operations.end() != m_operations.find( op->get_name() ) ) {
        cerr << "FATAL: Cannot add operation \"" 
             << op->get_name() << "\" because it already exists."
             << endl;
        exit( -1 );        
    }

    m_operations[ op->get_name() ] = op;
}

WSDLOperation* BPELModel::get_operation_by_name( const string& name )
{
    WSDLOperation* result = 0;
    if ( m_operations.end() != m_operations.find( name ) ) {
        result = m_operations[ name ];
    }
    return result;
}

void BPELModel::accept( ActivityVisitor* v )
{
    v->visit_bpel_model( this );
}
