/****************************************************************************
 *
 * CompositeActivity.hh
 *
 * This file is part of bpel2qnbound
 *
 * Copyright (C) 2007, 2018 Moreno Marzolla
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 ****************************************************************************/

#ifndef BPEL_COMPOSITEACTIVITY_HH
#define BPEL_COMPOSITEACTIVITY_HH

#include "Activity.hh"
#include <list>

/**
 * This class represents an abstract BPEL composite activity.  This is
 * a BPEL activity (such as "flow" or "sequence") which contains a
 * number of other activities.
 */
class CompositeActivity : public Activity {
protected:

    std::list< Activity* > m_content;

    CompositeActivity( const std::string& name );

public:
    virtual ~CompositeActivity( ) { };

    /**
     * Adds a new subactivity to the current one. 
     *
     * #param a the subactivity to add. Ownership is transferred to
     * this object; caller must not free a.
     */
    void add_activity( Activity* a );

    /**
     * Gets the content
     */
    std::list< Activity* > get_content( void ) const { return m_content; };
};

#endif
