/****************************************************************************
 *
 * WSDLOperation.hh
 *
 * This file is part of bpel2qnbound
 *
 * Copyright (C) 2007, 2018 Moreno Marzolla
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 ****************************************************************************/
#ifndef BPEL_WSDLOPERATION_HH
#define BPEL_WSDLOPERATION_HH

#include <string>
#include <map>

class WSDLOperation {
    static int s_id;

    const std::string m_name; ///< the name of this operation
    int m_id;
    std::map< std::string, double > m_service_time;
public:
    WSDLOperation( const std::string& name );
    ~WSDLOperation( ) { };

    /**
     * Sets the average service time for resource resource_name to
     * val.  Overwrites any existing value associated to
     * resource_name.
     */
    void set_service_time( const std::string& resource_name, double val );

    /**
     * Returns the average service time on resource resource_name;
     * returns 0 if the resource is not used by this operation.
     *
     * @param resource_name the name of a resource
     *
     * @return the average service time on resource resource_name for
     * this operation. Returns 0 if the resource is not used for this
     * operation.
     */
    double service_time( const std::string& resource_name ) const;

    /**
     * Returns the service time map for this operation
     */ 
    std::map< std::string, double > get_service_times( void ) const {
        return m_service_time;
    };

    std::string get_name( void ) const { return m_name; };

    int get_id( void ) const { return m_id; };

    void describe( void ) const;    
};

#endif
